@@ -160,6 +160,7 @@ goc_ellipse_distance (GocItem *item, double x, double y, GocItem **near_item)
 	GOStyle *style = go_styled_object_get_style (GO_STYLED_OBJECT (item));
 	double tmp_width = 0;
 	double res = 20;
+	double ppu = goc_canvas_get_pixels_per_unit (item->canvas);
 	cairo_surface_t *surface;
 	cairo_t *cr;
 
@@ -168,9 +169,10 @@ goc_ellipse_distance (GocItem *item, double x, double y, GocItem **near_item)
 
 	*near_item = item;
 	tmp_width = style->line.width;
-	if (style->line.width < 5){
-		style->line.width = 5;
-	}
+	if (style->line.width * ppu < 5)
+		style->line.width = 5. / (ppu * ppu);
+	else
+		style->line.width /= ppu;
 	surface = cairo_image_surface_create (CAIRO_FORMAT_ARGB32, 1, 1);
 	cr = cairo_create (surface);
 
